@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 Vaticle
+# Copyright (C) 2022 Vaticle
 #
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -19,11 +19,11 @@
 # under the License.
 #
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Iterator
+from typing import TYPE_CHECKING, Iterator, Optional
 
 from typedb.api.concept.thing.thing import Thing
-from typedb.api.concept.type.type import Type, RemoteType
 from typedb.api.concept.type.role_type import RoleType
+from typedb.api.concept.type.type import Type, RemoteType
 
 if TYPE_CHECKING:
     from typedb.api.concept.type.attribute_type import AttributeType
@@ -75,13 +75,29 @@ class RemoteThingType(RemoteType, ThingType, ABC):
         pass
 
     @abstractmethod
-    def get_plays(self) -> Iterator[RoleType]:
+    def get_plays(self) -> Iterator["RoleType"]:
+        pass
+
+    @abstractmethod
+    def get_plays_explicit(self) -> Iterator["RoleType"]:
+        pass
+
+    @abstractmethod
+    def get_plays_overridden(self, role_type: "RoleType") -> Optional["RoleType"]:
         pass
 
     @abstractmethod
     def get_owns(self, value_type: "AttributeType.ValueType" = None, keys_only: bool = False) -> Iterator["AttributeType"]:
         pass
 
+    @abstractmethod
+    def get_owns_explicit(self, value_type: "AttributeType.ValueType" = None, keys_only: bool = False) -> Iterator["AttributeType"]:
+        pass
+
+    @abstractmethod
+    def get_owns_overridden(self, attribute_type: "AttributeType") -> Optional["AttributeType"]:
+        pass
+
     @abstractmethod
     def unset_plays(self, role_type: "RoleType") -> None:
         pass
