@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 Vaticle
+# Copyright (C) 2022 Vaticle
 #
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -18,15 +18,14 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-from typing import Iterator, TYPE_CHECKING
 
 import typedb_protocol.common.concept_pb2 as concept_proto
 
-from typedb.api.concept.thing.relation import Relation
 from typedb.api.concept.type.relation_type import RelationType, RemoteRelationType
 from typedb.common.label import Label
 from typedb.common.rpc.request_builder import relation_type_create_req, relation_type_get_relates_req, \
-    relation_type_set_relates_req, relation_type_unset_relates_req
+    relation_type_set_relates_req, relation_type_unset_relates_req, relation_type_get_relates_explicit_req, \
+    relation_type_get_relates_overridden_req
 from typedb.concept.thing.relation import _Relation
 from typedb.concept.type.role_type import _RoleType
 from typedb.concept.type.thing_type import _ThingType, _RemoteThingType
@@ -58,11 +57,22 @@ class _RemoteRelationType(_RemoteThingType, RemoteRelationType):
 
     def get_relates(self, role_label: str = None):
         if role_label:
-            res = self.execute(relation_type_get_relates_req(self.get_label(), role_label)).relation_type_get_relates_for_role_label_res
+            res = self.execute(relation_type_get_relates_req(self.get_label(),
+                                                             role_label)).relation_type_get_relates_for_role_label_res
             return _RoleType.of(res.role_type) if res.HasField("role_type") else None
         else:
             return (_RoleType.of(rt) for rp in self.stream(relation_type_get_relates_req(self.get_label()))
-                    for rt in rp.relation_type_get_relates_res_part.roles)
+                    for rt in rp.relation_type_get_relates_res_part.role_types)
+
+    def get_relates_explicit(self):
+        return (_RoleType.of(rt) for rp in self.stream(relation_type_get_relates_explicit_req(self.get_label()))
+                for rt in rp.relation_type_get_relates_explicit_res_part.role_types)
+
+    def get_relates_overridden(self, role_label: str):
+        res = self.execute(relation_type_get_relates_overridden_req(
+            self.get_label(), role_label
+        )).relation_type_get_relates_overridden_res
+        return _RoleType.of(res.role_type) if res.HasField("role_type") else None
 
     def set_relates(self, role_label: str, overridden_label: str = None):
         self.execute(relation_type_set_relates_req(self.get_label(), role_label, overridden_label))
