@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 Vaticle
+# Copyright (C) 2022 Vaticle
 #
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -19,7 +19,7 @@
 # under the License.
 #
 from queue import Empty, Queue
-from typing import TypeVar, Iterator, Union, Generic, List
+from typing import TypeVar, Iterator, Union
 from uuid import uuid4, UUID
 
 import typedb_protocol.common.transaction_pb2 as transaction_proto
@@ -63,9 +63,6 @@ class BidirectionalStream:
         self._dispatcher.dispatch(req)
         return ResponsePartIterator(request_id, self)
 
-    def done(self, request_id: UUID):
-        self._response_collector.remove(request_id)
-
     def is_open(self) -> bool:
         return self._is_open.get()
 
@@ -103,7 +100,7 @@ class BidirectionalStream:
         if collector:
             collector.put(response)
         else:
-            raise TypeDBClientException.of(UNKNOWN_REQUEST_ID, request_id)
+            raise TypeDBClientException.of(UNKNOWN_REQUEST_ID, (request_id, str(response)))
 
     def dispatcher(self):
         return self._dispatcher
@@ -136,9 +133,7 @@ class BidirectionalStream:
             self._stream = stream
 
         def get(self) -> T:
-            value = self._stream.fetch(self._request_id)
-            self._stream.done(self._request_id)
-            return value
+            return self._stream.fetch(self._request_id)
 
 
 class RequestIterator(Iterator[Union[transaction_proto.Transaction.Req, StopIteration]]):
