@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 Vaticle
+# Copyright (C) 2022 Vaticle
 #
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -24,8 +24,8 @@ from threading import Lock
 from typing import Generic, TypeVar, Dict, Optional
 from uuid import UUID
 
-from typedb.common.exception import TypeDBClientException, TRANSACTION_CLOSED, ILLEGAL_STATE, \
-    TRANSACTION_CLOSED_WITH_ERRORS
+from grpc import RpcError
+from typedb.common.exception import TypeDBClientException, TRANSACTION_CLOSED, ILLEGAL_STATE
 
 R = TypeVar('R')
 
@@ -45,10 +45,6 @@ class ResponseCollector(Generic[R]):
     def get(self, request_id: UUID) -> Optional["ResponseCollector.Queue[R]"]:
         return self._response_queues.get(request_id)
 
-    def remove(self, request_id: UUID):
-        with self._collectors_lock:
-            del self._response_queues[request_id]
-
     def close(self, error: Optional[TypeDBClientException]):
         with self._collectors_lock:
             for collector in self._response_queues.values():
@@ -58,16 +54,15 @@ class ResponseCollector(Generic[R]):
 
         def __init__(self):
             self._response_queue: queue.Queue[Response] = queue.Queue()
-            self._error: TypeDBClientException = None
 
         def get(self, block: bool) -> R:
             response = self._response_queue.get(block=block)
             if response.is_value():
                 return response.value
-            elif response.is_done() and self._error is None:
+            elif response.is_done() and response.error is None:
                 raise TypeDBClientException.of(TRANSACTION_CLOSED)
-            elif response.is_done() and self._error is not None:
-                raise TypeDBClientException.of(TRANSACTION_CLOSED_WITH_ERRORS, self._error)
+            elif response.is_done() and response.error is not None:
+                raise TypeDBClientException.of_rpc(response.error)
             else:
                 raise TypeDBClientException.of(ILLEGAL_STATE)
 
@@ -75,9 +70,7 @@ class ResponseCollector(Generic[R]):
             self._response_queue.put(ValueResponse(response))
 
         def close(self, error: Optional[TypeDBClientException]):
-            self._error = error
-            self._response_queue.put(DoneResponse())
-
+            self._response_queue.put(DoneResponse(error))
 
 
 class Response:
@@ -100,8 +93,8 @@ class ValueResponse(Response, Generic[R]):
 
 class DoneResponse(Response):
 
-    def __init__(self):
-        pass
+    def __init__(self, error: Optional[RpcError]):
+        self.error = error
 
     def is_done(self):
         return True
