@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 Vaticle
+# Copyright (C) 2022 Vaticle
 #
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -74,10 +74,7 @@ class ResponsePartIterator(Iterator[transaction_proto.Transaction.ResPart]):
             raise TypeDBClientException.of(ILLEGAL_STATE)
 
     def __next__(self) -> transaction_proto.Transaction.ResPart:
-        if self._bidirectional_stream.get_error() is not None:
-            raise self._bidirectional_stream.get_error()
-        elif not self._has_next():
-            self._bidirectional_stream.done(self._request_id)
+        if not self._has_next():
             raise StopIteration
         else:
             self._state = ResponsePartIterator.State.EMPTY
